@@ -1,21 +1,22 @@
 # SPDX-FileCopyrightText: 2019 Free Software Foundation Europe e.V. <https://fsfe.org>
 # SPDX-FileCopyrightText: 2019 Kirill Elagin
 # SPDX-FileCopyrightText: 2020 Dmitry Bogatov
-# SPDX-FileCopyrightText: 2021-2022 Alliander N.V. <https://alliander.com>
 # SPDX-FileCopyrightText: 2021 Alvar Penning
-# SPDX-FileCopyrightText: 2021 Robin Vobruba <hoijui.quaero@gmail.com>
 # SPDX-FileCopyrightText: 2021 Matija Šuklje <matija@suklje.name>
+# SPDX-FileCopyrightText: 2021 Robin Vobruba <hoijui.quaero@gmail.com>
+# SPDX-FileCopyrightText: 2021-2022 Alliander N.V. <https://alliander.com>
+# SPDX-FileCopyrightText: 2022 Carmen Bianca Bakker <carmenbianca@fsfe.org>
 # SPDX-FileCopyrightText: 2022 Florian Snow <florian@familysnow.net>
 # SPDX-FileCopyrightText: 2022 Nico Rikken <nico.rikken@fsfe.org>
-# SPDX-FileCopyrightText: 2022 Stefan Hynek <stefan.hynek@uni-goettingen.de>
-# SPDX-FileCopyrightText: 2022 Carmen Bianca Bakker <carmenbianca@fsfe.org>
 # SPDX-FileCopyrightText: 2022 Sebastian Crane <seabass@fsfe.org>
-# SPDX-FileCopyrightText: 2023 Redradix S.L. <info@redradix.com>
+# SPDX-FileCopyrightText: 2022 Stefan Hynek <stefan.hynek@uni-goettingen.de>
+# SPDX-FileCopyrightText: 2023 Juelich Supercomputing Centre, Forschungszentrum Juelich GmbH
 # SPDX-FileCopyrightText: 2023 Kevin Meagher
 # SPDX-FileCopyrightText: 2023 Mathias Dannesbo <md@magenta.dk>
-# SPDX-FileCopyrightText: 2023 Shun Sakai <sorairolake@protonmail.ch>
-# SPDX-FileCopyrightText: 2023 Juelich Supercomputing Centre, Forschungszentrum Juelich GmbH
 # SPDX-FileCopyrightText: 2023 Maxim Cournoyer <maxim.cournoyer@gmail.com>
+# SPDX-FileCopyrightText: 2023 Redradix S.L. <info@redradix.com>
+# SPDX-FileCopyrightText: 2023 Shun Sakai <sorairolake@protonmail.ch>
+# SPDX-FileCopyrightText: 2024 Rivos Inc.
 #
 # SPDX-License-Identifier: GPL-3.0-or-later
 
@@ -321,6 +322,7 @@ class BibTexCommentStyle(CommentStyle):
     SHORTHAND = "bibtex"
 
     MULTI_LINE = MultiLineSegments("@Comment{", "", "}")
+    SHEBANGS = ["% !BIB", "%!BIB"]
 
 
 class CCommentStyle(CommentStyle):
@@ -328,6 +330,17 @@ class CCommentStyle(CommentStyle):
 
     SHORTHAND = "c"
 
+    MULTI_LINE = MultiLineSegments("/*", "*", "*/")
+    INDENT_BEFORE_MIDDLE = " "
+    INDENT_AFTER_MIDDLE = " "
+    INDENT_BEFORE_END = " "
+
+
+class CppCommentStyle(CommentStyle):
+    """C++ comment style."""
+
+    SHORTHAND = "cpp"
+
     SINGLE_LINE = "//"
     INDENT_AFTER_SINGLE = " "
     MULTI_LINE = MultiLineSegments("/*", "*", "*/")
@@ -340,26 +353,15 @@ class CCommentStyle(CommentStyle):
     ]
 
 
-class CSingleCommentStyle(CommentStyle):
-    """C single-only comment style."""
+class CppSingleCommentStyle(CommentStyle):
+    """C++ single-only comment style."""
 
-    SHORTHAND = "csingle"
+    SHORTHAND = "cppsingle"
 
     SINGLE_LINE = "//"
     INDENT_AFTER_SINGLE = " "
 
 
-class CssCommentStyle(CommentStyle):
-    """CSS comment style."""
-
-    SHORTHAND = "css"
-
-    MULTI_LINE = MultiLineSegments("/*", "*", "*/")
-    INDENT_BEFORE_MIDDLE = " "
-    INDENT_AFTER_MIDDLE = " "
-    INDENT_BEFORE_END = " "
-
-
 class EmptyCommentStyle(CommentStyle):
     """Hacky comment style for files that have no comments."""
 
@@ -525,6 +527,7 @@ class TexCommentStyle(CommentStyle):
 
     SINGLE_LINE = "%"
     INDENT_AFTER_SINGLE = " "
+    SHEBANGS = ["% !TEX", "%!TEX"]
 
 
 class UncommentableCommentStyle(EmptyCommentStyle):
@@ -533,6 +536,16 @@ class UncommentableCommentStyle(EmptyCommentStyle):
     """
 
 
+class UnixManCommentStyle(CommentStyle):
+    """UNIX manual page comment style."""
+
+    SHORTHAND = "man"
+
+    # In case the below is difficult to read, the comment character is: .\"
+    SINGLE_LINE = r".\""
+    INDENT_AFTER_SINGLE = " "
+
+
 class VelocityCommentStyle(CommentStyle):
     """Apache Velocity Template Language comment style."""
 
@@ -565,18 +578,19 @@ class XQueryCommentStyle(CommentStyle):
 #: A map of (common) file extensions against comment types.
 EXTENSION_COMMENT_STYLE_MAP = {
     ".adb": HaskellCommentStyle,
-    ".adoc": CCommentStyle,
+    ".adoc": CppCommentStyle,
     ".ads": HaskellCommentStyle,
     ".aes": UncommentableCommentStyle,
     ".ahk": SemicolonCommentStyle,
     ".ahkl": SemicolonCommentStyle,
-    ".aidl": CCommentStyle,
+    ".aidl": CppCommentStyle,
     ".applescript": AppleScriptCommentStyle,
     ".arb": UncommentableCommentStyle,
     ".asax": AspxCommentStyle,
-    ".asc": CCommentStyle,
-    ".asciidoc": CCommentStyle,
+    ".asc": CppCommentStyle,
+    ".asciidoc": CppCommentStyle,
     ".ashx": AspxCommentStyle,
+    ".asm": LispCommentStyle,  # ASM assembler
     ".asmx": AspxCommentStyle,
     ".aspx": AspxCommentStyle,
     ".aux": TexCommentStyle,
@@ -584,40 +598,47 @@ EXTENSION_COMMENT_STYLE_MAP = {
     ".axd": AspxCommentStyle,
     ".bash": PythonCommentStyle,
     ".bat": BatchFileCommentStyle,
+    ".bats": PythonCommentStyle,
     ".bb": PythonCommentStyle,
     ".bbappend": PythonCommentStyle,
     ".bbclass": PythonCommentStyle,
     ".bib": BibTexCommentStyle,
     ".bzl": PythonCommentStyle,
     ".c": CCommentStyle,
-    ".cc": CCommentStyle,
-    ".cjs": CCommentStyle,
+    ".cc": CppCommentStyle,
+    ".cjs": CppCommentStyle,
     ".cl": LispCommentStyle,
     ".clj": LispCommentStyle,
     ".cljc": LispCommentStyle,
     ".cljs": LispCommentStyle,
+    ".cls": TexCommentStyle,
     ".cmake": PythonCommentStyle,  # TODO: Bracket comments not supported.
-    ".code-workspace": CCommentStyle,
+    ".code-workspace": CppCommentStyle,
     ".coffee": PythonCommentStyle,
-    ".cpp": CCommentStyle,
-    ".cs": CCommentStyle,
+    ".cpp": CppCommentStyle,
+    ".cs": CppCommentStyle,
     ".csl": HtmlCommentStyle,  # Bibliography (XML based)
-    ".css": CssCommentStyle,
+    ".cson": PythonCommentStyle,
+    ".css": CCommentStyle,
+    ".csproj": HtmlCommentStyle,
     ".csv": UncommentableCommentStyle,
-    ".cxx": CCommentStyle,
-    ".d": CCommentStyle,
-    ".dart": CCommentStyle,
-    ".di": CCommentStyle,
+    ".cu": CppCommentStyle,
+    ".cuh": CppCommentStyle,
+    ".cxx": CppCommentStyle,
+    ".d": CppCommentStyle,
+    ".dart": CppCommentStyle,
+    ".di": CppCommentStyle,
     ".doc": UncommentableCommentStyle,
     ".docx": UncommentableCommentStyle,
     ".dotx": UncommentableCommentStyle,
-    ".dts": CCommentStyle,
-    ".dtsi": CCommentStyle,
+    ".dts": CppCommentStyle,
+    ".dtsi": CppCommentStyle,
     ".el": LispCommentStyle,
     ".erl": TexCommentStyle,
     ".ex": PythonCommentStyle,
     ".exs": PythonCommentStyle,
     ".f": FortranCommentStyle,
+    ".fsproj": HtmlCommentStyle,
     ".f03": ModernFortranCommentStyle,
     ".f08": ModernFortranCommentStyle,
     ".f90": ModernFortranCommentStyle,
@@ -630,54 +651,62 @@ EXTENSION_COMMENT_STYLE_MAP = {
     ".for": FortranCommentStyle,
     ".ftn": FortranCommentStyle,
     ".fpp": FortranCommentStyle,
-    ".fs": CCommentStyle,
+    ".fs": CppCommentStyle,
+    ".fsx": CppCommentStyle,
     ".ftl": FtlCommentStyle,
     ".gemspec": PythonCommentStyle,
-    ".go": CCommentStyle,
-    ".gradle": CCommentStyle,
+    ".go": CppCommentStyle,
+    ".gradle": CppCommentStyle,
     ".graphql": PythonCommentStyle,
-    ".groovy": CCommentStyle,
+    ".graphqls": PythonCommentStyle,
+    ".gqls": PythonCommentStyle,
+    ".groovy": CppCommentStyle,
     ".h": CCommentStyle,
-    ".ha": CSingleCommentStyle,
+    ".ha": CppSingleCommentStyle,
     ".hbs": HandlebarsCommentStyle,
     ".hcl": PythonCommentStyle,
-    ".hh": CCommentStyle,
-    ".hpp": CCommentStyle,
+    ".hh": CppCommentStyle,
+    ".hjson": CppCommentStyle,
+    ".hpp": CppCommentStyle,
     ".hrl": TexCommentStyle,
     ".hs": HaskellCommentStyle,
     ".html": HtmlCommentStyle,
-    ".hx": CCommentStyle,
-    ".hxsl": CCommentStyle,
+    ".hx": CppCommentStyle,
+    ".hxsl": CppCommentStyle,
     ".ini": SemicolonCommentStyle,
-    ".ino": CCommentStyle,
+    ".ino": CppCommentStyle,
     ".ipynb": UncommentableCommentStyle,
     ".iuml": PlantUmlCommentStyle,
-    ".java": CCommentStyle,
+    ".java": CppCommentStyle,
     ".jinja": JinjaCommentStyle,
     ".jinja2": JinjaCommentStyle,
     ".jl": JuliaCommentStyle,
     ".jpg": UncommentableCommentStyle,
     ".jpeg": UncommentableCommentStyle,
-    ".js": CCommentStyle,
+    ".js": CppCommentStyle,
     ".json": UncommentableCommentStyle,
+    ".json5": CppCommentStyle,
+    ".jsonc": CppCommentStyle,
     ".jsp": AspxCommentStyle,
-    ".jsx": CCommentStyle,
+    ".jsx": CppCommentStyle,
     ".jy": PythonCommentStyle,
     ".ksh": PythonCommentStyle,
-    ".kt": CCommentStyle,
-    ".kts": CCommentStyle,
+    ".kt": CppCommentStyle,
+    ".kts": CppCommentStyle,
     ".l": LispCommentStyle,
     ".latex": TexCommentStyle,
-    ".ld": CCommentStyle,
-    ".less": CssCommentStyle,
+    ".ld": CppCommentStyle,
+    ".less": CCommentStyle,
     ".license": EmptyCommentStyle,
     ".lisp": LispCommentStyle,
     ".lsp": LispCommentStyle,
     ".lua": HaskellCommentStyle,
+    ".m": TexCommentStyle,
     ".m4": M4CommentStyle,
+    ".man": UnixManCommentStyle,
     ".markdown": HtmlCommentStyle,
     ".md": HtmlCommentStyle,
-    ".mjs": CCommentStyle,
+    ".mjs": CppCommentStyle,
     ".mk": PythonCommentStyle,
     ".ml": MlCommentStyle,
     ".mli": MlCommentStyle,
@@ -699,10 +728,10 @@ EXTENSION_COMMENT_STYLE_MAP = {
     ".ott": UncommentableCommentStyle,
     ".pdf": UncommentableCommentStyle,
     ".pem": UncommentableCommentStyle,
-    ".php": CCommentStyle,
-    ".php3": CCommentStyle,
-    ".php4": CCommentStyle,
-    ".php5": CCommentStyle,
+    ".php": CppCommentStyle,
+    ".php3": CppCommentStyle,
+    ".php4": CppCommentStyle,
+    ".php5": CppCommentStyle,
     ".pl": PythonCommentStyle,
     ".plantuml": PlantUmlCommentStyle,
     ".png": UncommentableCommentStyle,
@@ -713,7 +742,9 @@ EXTENSION_COMMENT_STYLE_MAP = {
     ".pptx": UncommentableCommentStyle,
     ".pri": PythonCommentStyle,
     ".pro": PythonCommentStyle,
-    ".proto": CCommentStyle,
+    ".props": HtmlCommentStyle,  # MSBuild files
+    ".properties": PythonCommentStyle,
+    ".proto": CppCommentStyle,
     ".ps1": PythonCommentStyle,  # TODO: Multiline comments
     ".psm1": PythonCommentStyle,  # TODO: Multiline comments
     ".pu": PlantUmlCommentStyle,
@@ -723,10 +754,10 @@ EXTENSION_COMMENT_STYLE_MAP = {
     ".pyi": PythonCommentStyle,
     ".pyw": PythonCommentStyle,
     ".pyx": PythonCommentStyle,
-    ".qbs": CCommentStyle,
-    ".qml": CCommentStyle,
+    ".qbs": CppCommentStyle,
+    ".qml": CppCommentStyle,
     ".qrc": HtmlCommentStyle,
-    ".qss": CssCommentStyle,
+    ".qss": CCommentStyle,
     ".R": PythonCommentStyle,
     ".rake": PythonCommentStyle,
     ".rb": PythonCommentStyle,
@@ -734,32 +765,35 @@ EXTENSION_COMMENT_STYLE_MAP = {
     ".rbx": PythonCommentStyle,
     ".rkt": LispCommentStyle,
     ".Rmd": HtmlCommentStyle,
-    ".rs": CCommentStyle,
+    ".rs": CppCommentStyle,
     ".rss": HtmlCommentStyle,
     ".rst": ReStructedTextCommentStyle,
-    ".s": LispCommentStyle,
-    ".sass": CssCommentStyle,
-    ".sbt": CCommentStyle,
-    ".sc": CCommentStyle,  # SuperCollider source file
-    ".scad": CCommentStyle,
-    ".scala": CCommentStyle,
+    ".s": PythonCommentStyle,  # Assume GNU Assembler for x86
+    ".sass": CCommentStyle,
+    ".sbt": CppCommentStyle,
+    ".sc": CppCommentStyle,  # SuperCollider source file
+    ".scad": CppCommentStyle,
+    ".scala": CppCommentStyle,
     ".scm": LispCommentStyle,
     ".scpt": AppleScriptCommentStyle,
     ".scptd": AppleScriptCommentStyle,
-    ".scss": CssCommentStyle,
+    ".scss": CCommentStyle,
     # SuperCollider synth definition (binary)
     ".scsyndef": UncommentableCommentStyle,
     ".sh": PythonCommentStyle,
     ".sld": LispCommentStyle,  # Scheme Library Definition (R7RS)
+    # Visual Studio solution file, officially uncommentable:
+    ".sln": UncommentableCommentStyle,
     ".sls": LispCommentStyle,  # Scheme Library Source (R6RS)
     ".sml": MlCommentStyle,
-    ".soy": CCommentStyle,
+    ".soy": CppCommentStyle,
     ".sps": LispCommentStyle,  # Scheme Program Source (R6RS)
     ".sql": HaskellCommentStyle,
     ".sty": TexCommentStyle,
     ".svg": UncommentableCommentStyle,
     ".svelte": HtmlCommentStyle,
-    ".swift": CCommentStyle,
+    ".swift": CppCommentStyle,
+    ".t": PythonCommentStyle,
     ".tcl": PythonCommentStyle,
     ".tex": TexCommentStyle,
     ".textile": HtmlCommentStyle,
@@ -768,16 +802,18 @@ EXTENSION_COMMENT_STYLE_MAP = {
     ".thy": MlCommentStyle,
     ".toc": TexCommentStyle,
     ".toml": PythonCommentStyle,
-    ".ts": CCommentStyle,
-    ".tsx": CCommentStyle,
+    ".ts": CppCommentStyle,
+    ".tsx": CppCommentStyle,
     ".ttl": PythonCommentStyle,  # Turtle/RDF
-    ".typ": CCommentStyle,  # typst files
+    ".typ": CppCommentStyle,  # typst files
     ".ui": HtmlCommentStyle,
-    ".v": CCommentStyle,  # V-Lang source code
-    ".vala": CCommentStyle,
+    ".v": CppCommentStyle,  # V-Lang source code
+    ".vala": CppCommentStyle,
+    ".vbproj": HtmlCommentStyle,
+    ".vhdl": HaskellCommentStyle,
     ".vim": VimCommentStyle,
     ".vm": VelocityCommentStyle,
-    ".vsh": CCommentStyle,  # V-Lang script
+    ".vsh": CppCommentStyle,  # V-Lang script
     ".vtl": VelocityCommentStyle,
     ".vue": HtmlCommentStyle,
     ".webp": UncommentableCommentStyle,
@@ -794,7 +830,7 @@ EXTENSION_COMMENT_STYLE_MAP = {
     ".xsl": HtmlCommentStyle,
     ".yaml": PythonCommentStyle,
     ".yml": PythonCommentStyle,
-    ".zig": CSingleCommentStyle,
+    ".zig": CppSingleCommentStyle,
     ".zsh": PythonCommentStyle,
 }
 
@@ -808,8 +844,10 @@ FILENAME_COMMENT_STYLE_MAP = {
     ".bazelrc": PythonCommentStyle,
     ".browserslist": PythonCommentStyle,
     ".clang-format": PythonCommentStyle,
+    ".clang-tidy": PythonCommentStyle,
     ".coveragerc": PythonCommentStyle,
     ".dockerignore": PythonCommentStyle,
+    ".earthlyignore": PythonCommentStyle,
     ".editorconfig": PythonCommentStyle,
     ".empty": EmptyCommentStyle,
     ".eslintignore": PythonCommentStyle,
@@ -817,32 +855,37 @@ FILENAME_COMMENT_STYLE_MAP = {
     ".gitattributes": PythonCommentStyle,
     ".gitignore": PythonCommentStyle,
     ".gitmodules": PythonCommentStyle,
+    ".htaccess": PythonCommentStyle,
     ".mailmap": PythonCommentStyle,
     ".metadata": UncommentableCommentStyle,
     ".mdlrc": PythonCommentStyle,  # Markdown-linter config
     ".npmignore": PythonCommentStyle,
+    ".npmrc": SemicolonCommentStyle,
     ".prettierrc": UncommentableCommentStyle,  # could either be JSON or YAML
     ".prettierignore": PythonCommentStyle,
     ".pylintrc": PythonCommentStyle,
     ".Renviron": PythonCommentStyle,
     ".Rprofile": PythonCommentStyle,
     ".shellcheckrc": PythonCommentStyle,
+    ".taprc": PythonCommentStyle,
     ".vimrc": VimCommentStyle,
+    ".zshrc": PythonCommentStyle,
     ".yarnrc": PythonCommentStyle,
     "ansible.cfg": PythonCommentStyle,
     "archive.sctxar": UncommentableCommentStyle,  # SuperCollider global archive
+    "Cargo.lock": UncommentableCommentStyle,
     "CMakeLists.txt": PythonCommentStyle,
     "CODEOWNERS": PythonCommentStyle,
     "configure.ac": M4CommentStyle,
     "Containerfile": PythonCommentStyle,
     "Dockerfile": PythonCommentStyle,
     "Doxyfile": PythonCommentStyle,
+    "Earthfile": PythonCommentStyle,
     "Gemfile": PythonCommentStyle,
-    "go.mod": CCommentStyle,
+    "go.mod": CppCommentStyle,
     "go.sum": UncommentableCommentStyle,
-    "gradle-wrapper.properties": PythonCommentStyle,
     "gradlew": PythonCommentStyle,
-    "Jenkinsfile": CCommentStyle,
+    "Jenkinsfile": CppCommentStyle,
     "Makefile.am": PythonCommentStyle,
     "Makefile": PythonCommentStyle,
     "MANIFEST.in": PythonCommentStyle,
@@ -855,7 +898,6 @@ FILENAME_COMMENT_STYLE_MAP = {
     "requirements.txt": PythonCommentStyle,
     "ROOT": MlCommentStyle,
     "setup.cfg": PythonCommentStyle,
-    "sonar-project.properties": PythonCommentStyle,
     "yarn.lock": UncommentableCommentStyle,
 }
 
